package IOD::Examples;

our $DATE = '2015-03-26'; # DATE
our $VERSION = '0.13'; # VERSION

1;
# ABSTRACT: Example IOD configuration files

__END__

=pod

=encoding UTF-8

=head1 NAME

IOD::Examples - Example IOD configuration files

=head1 VERSION

This document describes version 0.13 of IOD::Examples (from Perl distribution IOD-Examples), released on 2015-03-26.

=head1 DESCRIPTION

This distribution contains various examples of L<IOD> configuration files in its
per-dist share dir. It also serves as a spectest.

=head1 SEE ALSO

L<IOD>

L<Config::IOD>, L<Config::IOD::Reader>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/IOD-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-IOD-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=IOD-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
